@@ -1,11 +1,10 @@
 import React from "react";
-import Test from "./components/Test";
+import Hello from "./components/Hello";
 
 function App() {
   return (
     <div>
-      <h1>React app</h1>
-      <Test />
+      <Hello />
     </div>
   );
 }
